==> samples-js-angular-1-1.9.0.tgz: package/test/e2e/conf.js <==
/*!
 * Copyright (c) 2015-2016, Okta, Inc. and/or its affiliates. All rights reserved.
 * The Okta software accompanied by this notice is provided pursuant to the Apache License, Version 2.0 (the "License.")
 *
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0.
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *
 * See the License for the specific language governing permissions and limitations under the License.
 */

/* eslint import/no-unresolved:0, import/no-extraneous-dependencies:0, no-console:0 */
/* global jasmine */
const jasmineReporters = require('jasmine-reporters');
const startAndWaitFor = require('../../tools/start-and-wait-for');
const samplesConfig = require('../../.samples.config.json').oktaSample;

const promises = Promise.all([
  startAndWaitFor('npm', ['start'], samplesConfig.server.startSignal, 'green'),
  startAndWaitFor('npm', ['run', 'mock-okta'], 'Proxying:', 'magenta'),
]);

const config = {
  framework: 'jasmine2',
  beforeLaunch() {
    return promises;
  },
  onPrepare() {
    jasmine.getEnv().addReporter(new jasmineReporters.JUnitXmlReporter({
      savePath: 'build2/reports/junit',
      filePrefix: 'results',
    }));
  },
  afterLaunch() {
    promises.then((childProcesses) => {
      childProcesses.forEach(child => process.kill(-child.pid));
    });
    return new Promise(resolve => setTimeout(() => resolve(), 1000));
  },
  specs: ['specs/*.js'],
  restartBrowserBetweenTests: false,
  capabilities: {},
};

// Run PhantomJs in Travis, else Chrome
if (process.env.TRAVIS) {
  config.capabilities.browserName = 'phantomjs';
} else {
  config.capabilities.browserName = 'chrome';
}

module.exports.config = config;

==> samples-js-angular-1-1.12.0.tgz: package/test/e2e/conf.js <==
/*!
 * Copyright (c) 2015-2016, Okta, Inc. and/or its affiliates. All rights reserved.
 * The Okta software accompanied by this notice is provided pursuant to the Apache License, Version 2.0 (the "License.")
 *
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0.
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *
 * See the License for the specific language governing permissions and limitations under the License.
 */

/* eslint import/no-unresolved:0, import/no-extraneous-dependencies:0, no-console:0 */
/* global jasmine */
const jasmineReporters = require('jasmine-reporters');
const daemonUtil = require('../../tools/daemon-util');

const promises = Promise.all([
  daemonUtil.startAppServer(),
  daemonUtil.startMockOkta(),
]);

const config = {
  framework: 'jasmine2',
  beforeLaunch() {
    return promises;
  },
  onPrepare() {
    jasmine.getEnv().addReporter(new jasmineReporters.JUnitXmlReporter({
      savePath: 'build2/reports/junit',
      filePrefix: 'results',
    }));
  },
  afterLaunch() {
    promises.then((childProcesses) => {
      childProcesses.forEach(child => child.stop());
    });
    return new Promise(resolve => setTimeout(() => resolve(), 1000));
  },
  specs: ['specs/*.js'],
  restartBrowserBetweenTests: false,
  capabilities: {},
};

// Run PhantomJs in Travis, else Chrome
if (process.env.TRAVIS) {
  config.capabilities.browserName = 'phantomjs';
} else {
  config.capabilities.browserName = 'chrome';
}

module.exports.config = config;
